@@ -1,16 +1,16 @@
 /*
     Copyright 2013 by Reza Fatahilah Shah <rshah0385@kireihana.com>
- 
+
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
-   
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-   
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -21,7 +21,7 @@
 #include <KSharedConfig>
 
 class ThemeConfig;
-class AdvanceConfig;
+class AdvancedConfig;
 
 class SddmKcm : public KCModule
 {
@@ -35,11 +35,12 @@ public Q_SLOTS:
 
 private:
     void prepareUi();
-    
+
 private:
     KSharedConfigPtr mSddmConfig;
+    KSharedConfigPtr mSddmOldConfig;
     ThemeConfig *mThemeConfig;
-    AdvanceConfig *mAdvanceConfig;
+    AdvancedConfig *mAdvancedConfig;
 };
 
 #endif // SDDMKCM_H
